@@ -5,10 +5,10 @@
  *
  * Written by Russ Allbery <eagle@eyrie.org>
  * Copyright 2016 Russ Allbery <eagle@eyrie.org>
- * Copyright 2013, 2014
+ * Copyright 2013-2014
  *     The Board of Trustees of the Leland Stanford Junior University
  *
- * See LICENSE for licensing terms.
+ * SPDX-License-Identifier: MIT
  */
 
 #include <config.h>
@@ -48,10 +48,14 @@ analyze_password(const char *password, struct password_classes *classes)
         else
             classes->symbol = true;
     }
-    if (classes->lower)  classes->num_classes++;
-    if (classes->upper)  classes->num_classes++;
-    if (classes->digit)  classes->num_classes++;
-    if (classes->symbol) classes->num_classes++;
+    if (classes->lower)
+        classes->num_classes++;
+    if (classes->upper)
+        classes->num_classes++;
+    if (classes->digit)
+        classes->num_classes++;
+    if (classes->symbol)
+        classes->num_classes++;
 }
 
 
